lang = require("lang.localize")
inifile = require("inifile")

font = love.graphics.newFont("unifont-7.0.06.ttf", 16)
love.graphics.setFont(font)

rkey = nil
locales = {}
-- time when the game was started
started = os.time()

function load_locale(locale)
  lang.set_locale(locale)
  -- parse the ini file
  local ini = inifile.parse("data/" .. locale .. ".ini")
  -- import the text from the ini file
  for name, section in pairs(ini) do
    for key, text in pairs(section) do
      -- make sure all text is in string format
      if type(text) == "number" then
        text = tostring(text)
      end
      if type(text) == "string" then
        lang.set_text(name .. "." .. key, text)
      end
    end
  end
end

function love.load()
  -- iterate all locale files
  local files = love.filesystem.getDirectoryItems("data")
  for _, file in ipairs(files) do
    local locale = string.sub(file, 1, 2)
    table.insert(locales, locale)
  end
  load_locale("en")
end

function love.update(dt)
  
end

function love.draw()
  love.graphics.print("Arrow keys: switch locales", 10, 10)
  love.graphics.print("Any other key: get a random string", 10, 30)

  love.graphics.print(lang.get_locale(), 10, 70)
  love.graphics.print(lang.get_text("lang.nameen"), 10, 90)
  love.graphics.print(lang.get_text("lang.name"), 10, 110)

  -- some stats about the locale file
  local keys = lang.get_keys()
  local keys2 = lang.get_keys_locale("en")
  love.graphics.print(#keys .. "/" .. #keys2 .. " strings", 10, 150)
  
  -- date/time functions
  local now = os.time()
  local seconds = math.floor(now - started)
  love.graphics.print("Started: " .. lang.get_text("date.bseconds", seconds), 10, 170)
  
  local year = os.date("%Y")
  local seconds = os.time({ year = year + 1, day = 1, month = 1 }) - now
  local days = math.floor(seconds/60/60/24)
  local date = lang.get_text("date.adays", days)
  love.graphics.print("New year: " .. date, 10, 190)
  
  -- samplar string
  local samplar = lang.get_samplar()
  love.graphics.print("Samplar: " .. samplar, 10, 210)

  -- random string
  if rkey then
    love.graphics.print("Random string: ", 10, 250)
    love.graphics.print(lang.get_text(rkey), 10, 270)
  end
end

function love.keypressed(k, r)
  -- iterate locales using the keyboard
  local i = 1
  --local locales = lang.get_available()
  for k, locale in ipairs(locales) do
    if locale == lang.get_locale() then
      i = k
      break
    end
  end
  local j = i
  if k == "up" or k == "left" then
    j = j - 1
    if j < 1 then
      j = #locales
    end
  elseif k == "down" or k == "right" then
    j = j + 1
    if j > #locales then
      j = 1
    end
  else
    local keys = lang.get_keys()
    rkey = keys[math.random(#keys)]
  end
  if j ~= i then
    --lang.set_locale(locales[i])
    load_locale(locales[j])
  end
end